define(["require", "exports", "react", "react-dom", "@fluentui/react/lib/Theme", "@fluentui/react/lib/WindowProvider"], function (require, exports, React, ReactDOM, Theme_1, WindowProvider_1) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.createUIUtilities = void 0;
    /**
     * Create the UI Utilities object for plugins to render additional react components
     * @param container Container DIV of editor
     * @param theme Current theme used by editor
     * @returns A UIUtilities object
     */
    function createUIUtilities(container, theme) {
        return {
            renderComponent: function (element) {
                var doc = container.ownerDocument;
                var div = doc.createElement('div');
                doc.body.appendChild(div);
                ReactDOM.render(React.createElement(WindowProvider_1.WindowProvider, { window: doc.defaultView },
                    React.createElement(Theme_1.ThemeProvider, { theme: theme }, element)), div);
                return function () {
                    ReactDOM.unmountComponentAtNode(div);
                    doc.body.removeChild(div);
                };
            },
            isRightToLeft: function () {
                var _a;
                var dir = container &&
                    ((_a = container.ownerDocument.defaultView) === null || _a === void 0 ? void 0 : _a.getComputedStyle(container).direction);
                return dir == 'rtl';
            },
        };
    }
    exports.createUIUtilities = createUIUtilities;
});
//# sourceMappingURL=createUIUtilities.js.map