define(["require", "exports", "../utils/createContextMenuProvider", "roosterjs-content-model-dom", "roosterjs-content-model-api", "../../inputDialog/utils/showInputDialog"], function (require, exports, createContextMenuProvider_1, roosterjs_content_model_dom_1, roosterjs_content_model_api_1, showInputDialog_1) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.createListEditMenuProvider = void 0;
    var ListNumberResetMenuItem = {
        key: 'menuNameListNumberReset',
        unlocalizedText: 'Restart at 1',
        onClick: function (_, editor, node) {
            (0, roosterjs_content_model_api_1.setListStartNumber)(editor, 1);
        },
    };
    var ListNumberEditMenuItem = {
        key: 'menuNameListNumberEdit',
        unlocalizedText: 'Set numbering value',
        onClick: function (_, editor, node, strings, uiUtilities) {
            var listAndLi = getEditingList(editor, node);
            if (listAndLi) {
                var list = listAndLi.list, li = listAndLi.li;
                var startNumber_1 = list.start;
                for (var child = list.firstChild; child; child = child.nextSibling) {
                    if (child === li) {
                        break;
                    }
                    else if ((0, roosterjs_content_model_dom_1.isNodeOfType)(child, 'ELEMENT_NODE') && (0, roosterjs_content_model_dom_1.isElementOfType)(child, 'li')) {
                        startNumber_1 += 1;
                    }
                }
                (0, showInputDialog_1.showInputDialog)(uiUtilities, 'menuNameListNumberEdit', 'Set numbering value', {
                    value: {
                        labelKey: 'dialogTextSetListNumber',
                        unlocalizedLabel: 'Set value to',
                        initValue: startNumber_1.toString(),
                    },
                }, strings).then(function (values) {
                    editor.focus();
                    if (values) {
                        var result = parseInt(values.value);
                        if (result > 0 && result != startNumber_1) {
                            (0, roosterjs_content_model_api_1.setListStartNumber)(editor, Math.floor(result));
                        }
                    }
                });
            }
        },
    };
    function getEditingList(editor, node) {
        var domHelper = editor.getDOMHelper();
        var li = domHelper.findClosestElementAncestor(node, 'LI');
        var list = li && domHelper.findClosestElementAncestor(li, 'ol');
        return (list === null || list === void 0 ? void 0 : list.isContentEditable) ? { list: list, li: li } : null;
    }
    /**
     * Create a new instance of ContextMenuProvider to support list number editing functionalities in context menu
     * @returns A new ContextMenuProvider
     */
    function createListEditMenuProvider(strings) {
        return (0, createContextMenuProvider_1.createContextMenuProvider)('listEdit', [ListNumberResetMenuItem, ListNumberEditMenuItem], strings, function (editor, node) { return !!getEditingList(editor, node); });
    }
    exports.createListEditMenuProvider = createListEditMenuProvider;
});
//# sourceMappingURL=createListEditMenuProvider.js.map