define(["require", "exports", "react", "../utils/buttons", "roosterjs-content-model-dom", "roosterjs-content-model-core", "../component/showPasteOptionPane"], function (require, exports, React, buttons_1, roosterjs_content_model_dom_1, roosterjs_content_model_core_1, showPasteOptionPane_1) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.createPasteOptionPlugin = void 0;
    var PasteOptionPlugin = /** @class */ (function () {
        function PasteOptionPlugin(strings) {
            var _this = this;
            this.strings = strings;
            this.clipboardData = null;
            this.editor = null;
            this.uiUtilities = null;
            this.pasteOptionRef = React.createRef();
            this.onPaste = function (key) {
                var _a;
                if (_this.clipboardData && _this.editor) {
                    _this.editor.focus();
                    switch (key) {
                        case 'pasteOptionPasteAsIs':
                            (0, roosterjs_content_model_core_1.paste)(_this.editor, _this.clipboardData);
                            break;
                        case 'pasteOptionPasteText':
                            (0, roosterjs_content_model_core_1.paste)(_this.editor, _this.clipboardData, 'asPlainText');
                            break;
                        case 'pasteOptionMergeFormat':
                            (0, roosterjs_content_model_core_1.paste)(_this.editor, _this.clipboardData, 'mergeFormat');
                            break;
                        case 'pasteOptionPasteAsImage':
                            (0, roosterjs_content_model_core_1.paste)(_this.editor, _this.clipboardData, 'asImage');
                    }
                    (_a = _this.pasteOptionRef.current) === null || _a === void 0 ? void 0 : _a.setSelectedKey(key);
                }
            };
        }
        PasteOptionPlugin.prototype.getName = function () {
            return 'PasteOption';
        };
        PasteOptionPlugin.prototype.initialize = function (editor) {
            this.editor = editor;
        };
        PasteOptionPlugin.prototype.dispose = function () {
            var _a;
            (_a = this.pasteOptionRef.current) === null || _a === void 0 ? void 0 : _a.dismiss();
            this.editor = null;
        };
        PasteOptionPlugin.prototype.onPluginEvent = function (event) {
            var _a;
            if (!this.editor) {
                return;
            }
            if (event.eventType == 'scroll') {
                if (this.pasteOptionRef.current) {
                    this.showPasteOptionPane(this.editor);
                }
            }
            else if (this.pasteOptionRef.current) {
                this.handlePasteOptionPaneEvent(event);
            }
            else if (event.eventType == 'contentChanged') {
                if (event.source == roosterjs_content_model_dom_1.ChangeSource.Paste) {
                    var clipboardData = event.data;
                    // Only show paste option when we pasted HTML with some format
                    if ((clipboardData === null || clipboardData === void 0 ? void 0 : clipboardData.text) && ((_a = clipboardData.types) === null || _a === void 0 ? void 0 : _a.indexOf('text/html')) >= 0) {
                        this.clipboardData = clipboardData;
                        this.showPasteOptionPane(this.editor);
                    }
                }
            }
        };
        PasteOptionPlugin.prototype.setUIUtilities = function (uiUtilities) {
            this.uiUtilities = uiUtilities;
        };
        PasteOptionPlugin.prototype.handlePasteOptionPaneEvent = function (event) {
            var _a;
            if (event.eventType == 'keyDown' && this.pasteOptionRef.current) {
                var selectedKey = this.pasteOptionRef.current.getSelectedKey();
                if (!selectedKey) {
                    switch (event.rawEvent.key) {
                        case 'Control':
                            this.pasteOptionRef.current.setSelectedKey(buttons_1.ButtonKeys[0]);
                            cancelEvent(event.rawEvent);
                            break;
                        case 'Escape':
                            this.pasteOptionRef.current.dismiss();
                            cancelEvent(event.rawEvent);
                            break;
                        default:
                            this.pasteOptionRef.current.dismiss();
                            break;
                    }
                }
                else {
                    var keyboardEvent = event.rawEvent;
                    if (keyboardEvent.key != 'Control' && keyboardEvent.ctrlKey) {
                        // Dismiss the paste option when pressing hotkey CTRL+<any key>
                        this.pasteOptionRef.current.dismiss();
                        return;
                    }
                    for (var i = 0; i < buttons_1.ButtonKeys.length; i++) {
                        var key = buttons_1.ButtonKeys[i];
                        var button = buttons_1.Buttons[key];
                        if (button.shortcut == String.fromCharCode(keyboardEvent.which)) {
                            this.onPaste(key);
                            cancelEvent(keyboardEvent);
                            return;
                        }
                    }
                    switch (keyboardEvent.key) {
                        case 'Escape':
                            this.pasteOptionRef.current.dismiss();
                            break;
                        case 'ArrowLeft':
                        case 'ArrowRight':
                            var buttonCount = buttons_1.ButtonKeys.length;
                            var diff = (keyboardEvent.key == 'ArrowRight') == ((_a = this.uiUtilities) === null || _a === void 0 ? void 0 : _a.isRightToLeft())
                                ? -1
                                : 1;
                            this.pasteOptionRef.current.setSelectedKey(buttons_1.ButtonKeys[(buttons_1.ButtonKeys.indexOf(selectedKey) + diff + buttonCount) % buttonCount]);
                            break;
                        case 'Enter':
                            this.onPaste(selectedKey);
                            break;
                        case 'Control':
                            // Noop
                            break;
                        default:
                            this.pasteOptionRef.current.dismiss();
                            return;
                    }
                    cancelEvent(keyboardEvent);
                }
            }
        };
        PasteOptionPlugin.prototype.showPasteOptionPane = function (editor) {
            var _a;
            (_a = this.pasteOptionRef.current) === null || _a === void 0 ? void 0 : _a.dismiss();
            var selection = editor.getDOMSelection();
            if ((selection === null || selection === void 0 ? void 0 : selection.type) == 'range' && this.uiUtilities) {
                (0, showPasteOptionPane_1.showPasteOptionPane)(this.uiUtilities, selection.range.startContainer, selection.range.startOffset, this.onPaste, this.pasteOptionRef, this.strings);
            }
        };
        return PasteOptionPlugin;
    }());
    function cancelEvent(event) {
        event.preventDefault();
        event.stopPropagation();
    }
    /**
     * Create a new instance of PasteOption plugin to show an option pane when paste, so that user can choose
     * an option to change the paste result, including:
     * - Paste as is
     * - Paste as text
     * - Paste and merge format
     * @param strings Localized string for this plugin
     * @returns A paste option plugin
     */
    function createPasteOptionPlugin(strings) {
        return new PasteOptionPlugin(strings);
    }
    exports.createPasteOptionPlugin = createPasteOptionPlugin;
});
//# sourceMappingURL=createPasteOptionPlugin.js.map