import * as React from 'react';
import { BackgroundColorDropDownItems, BackgroundColors } from '../utils/backgroundColors';
import { mergeStyleSets } from '@fluentui/react/lib/Styling';
import { TextColorDropDownItems, TextColors } from '../utils/textColors';
import { getColorPickerContainerClassName, getColorPickerItemClassName, } from '../utils/getClassNamesForColorPicker';
var classNames = mergeStyleSets({
    colorSquare: {
        width: '20px',
        height: '20px',
        margin: '4px',
        borderStyle: 'solid',
        borderWidth: '2px',
        '&:hover': {
            borderColor: 'red',
        },
    },
    colorSquareBorder: {
        borderColor: 'transparent',
    },
    colorSquareBorderWhite: {
        borderColor: '#bebebe',
    },
});
/**
 * @internal
 * Render a color picker
 * @param item Color items
 * @param colorDef Definition of colors
 * @param onClick On click event handler
 */
export function renderColorPicker(item, colorDef, onClick) {
    var key = item.key;
    var buttonColor = colorDef[key].lightModeColor;
    return (React.createElement("button", { onClick: function (e) { return onClick(e, item); }, title: item.text },
        React.createElement("div", { className: classNames.colorSquare +
                ' ' +
                (key == 'textColorWhite' || key == 'backgroundColorWhite'
                    ? classNames.colorSquareBorderWhite
                    : classNames.colorSquareBorder), style: {
                backgroundColor: buttonColor,
            } })));
}
/**
 * Get a drop down data object of color picker used by drop down button
 * @param colorSet The set of color, text or background
 * @returns The color picker drop down for ribbon button
 */
export function getColorPickerDropDown(colorSet) {
    return {
        items: colorSet == 'background' ? BackgroundColorDropDownItems : TextColorDropDownItems,
        itemClassName: getColorPickerItemClassName(),
        allowLivePreview: true,
        itemRender: colorSet == 'background'
            ? function (item, onClick) { return renderColorPicker(item, BackgroundColors, onClick); }
            : function (item, onClick) { return renderColorPicker(item, TextColors, onClick); },
        commandBarSubMenuProperties: {
            className: getColorPickerContainerClassName(),
        },
    };
}
//# sourceMappingURL=renderColorPicker.js.map