import { createContextMenuProvider } from '../utils/createContextMenuProvider';
import { isElementOfType, isNodeOfType } from 'roosterjs-content-model-dom';
import { setListStartNumber } from 'roosterjs-content-model-api';
import { showInputDialog } from '../../inputDialog/utils/showInputDialog';
var ListNumberResetMenuItem = {
    key: 'menuNameListNumberReset',
    unlocalizedText: 'Restart at 1',
    onClick: function (_, editor, node) {
        setListStartNumber(editor, 1);
    },
};
var ListNumberEditMenuItem = {
    key: 'menuNameListNumberEdit',
    unlocalizedText: 'Set numbering value',
    onClick: function (_, editor, node, strings, uiUtilities) {
        var listAndLi = getEditingList(editor, node);
        if (listAndLi) {
            var list = listAndLi.list, li = listAndLi.li;
            var startNumber_1 = list.start;
            for (var child = list.firstChild; child; child = child.nextSibling) {
                if (child === li) {
                    break;
                }
                else if (isNodeOfType(child, 'ELEMENT_NODE') && isElementOfType(child, 'li')) {
                    startNumber_1 += 1;
                }
            }
            showInputDialog(uiUtilities, 'menuNameListNumberEdit', 'Set numbering value', {
                value: {
                    labelKey: 'dialogTextSetListNumber',
                    unlocalizedLabel: 'Set value to',
                    initValue: startNumber_1.toString(),
                },
            }, strings).then(function (values) {
                editor.focus();
                if (values) {
                    var result = parseInt(values.value);
                    if (result > 0 && result != startNumber_1) {
                        setListStartNumber(editor, Math.floor(result));
                    }
                }
            });
        }
    },
};
function getEditingList(editor, node) {
    var domHelper = editor.getDOMHelper();
    var li = domHelper.findClosestElementAncestor(node, 'LI');
    var list = li && domHelper.findClosestElementAncestor(li, 'ol');
    return (list === null || list === void 0 ? void 0 : list.isContentEditable) ? { list: list, li: li } : null;
}
/**
 * Create a new instance of ContextMenuProvider to support list number editing functionalities in context menu
 * @returns A new ContextMenuProvider
 */
export function createListEditMenuProvider(strings) {
    return createContextMenuProvider('listEdit', [ListNumberResetMenuItem, ListNumberEditMenuItem], strings, function (editor, node) { return !!getEditingList(editor, node); });
}
//# sourceMappingURL=createListEditMenuProvider.js.map