import { __assign } from "tslib";
import { createContextMenuProvider } from '../utils/createContextMenuProvider';
import { editTable, setTableCellShade } from 'roosterjs-content-model-api';
import { renderColorPicker } from '../../colorPicker/component/renderColorPicker';
import { getColorPickerContainerClassName, getColorPickerItemClassName, } from '../../colorPicker/utils/getClassNamesForColorPicker';
import { BackgroundColorDropDownItems, BackgroundColors, } from '../../colorPicker/utils/backgroundColors';
var TableEditOperationMap = {
    menuNameTableInsertAbove: 'insertAbove',
    menuNameTableInsertBelow: 'insertBelow',
    menuNameTableInsertLeft: 'insertLeft',
    menuNameTableInsertRight: 'insertRight',
    menuNameTableDeleteTable: 'deleteTable',
    menuNameTableDeleteColumn: 'deleteColumn',
    menuNameTableDeleteRow: 'deleteRow',
    menuNameTableMergeAbove: 'mergeAbove',
    menuNameTableMergeBelow: 'mergeBelow',
    menuNameTableMergeLeft: 'mergeLeft',
    menuNameTableMergeRight: 'mergeRight',
    menuNameTableMergeCells: 'mergeCells',
    menuNameTableSplitHorizontally: 'splitHorizontally',
    menuNameTableSplitVertically: 'splitVertically',
    menuNameTableAlignLeft: 'alignCellLeft',
    menuNameTableAlignCenter: 'alignCellCenter',
    menuNameTableAlignRight: 'alignCellRight',
    menuNameTableAlignTop: 'alignCellTop',
    menuNameTableAlignMiddle: 'alignCellMiddle',
    menuNameTableAlignBottom: 'alignCellBottom',
    menuNameTableAlignTableLeft: 'alignLeft',
    menuNameTableAlignTableCenter: 'alignCenter',
    menuNameTableAlignTableRight: 'alignRight',
};
var ColorValues = __assign(__assign({}, BackgroundColors), { 
    // Add this value to satisfy compiler
    menuNameTableCellShade: null });
function onClick(key, editor) {
    var operation = TableEditOperationMap[key];
    if (operation) {
        editTable(editor, operation);
    }
}
var TableEditInsertMenuItem = {
    key: 'menuNameTableInsert',
    unlocalizedText: 'Insert',
    subItems: {
        menuNameTableInsertAbove: 'Insert above',
        menuNameTableInsertBelow: 'Insert below',
        menuNameTableInsertLeft: 'Insert left',
        menuNameTableInsertRight: 'Insert right',
    },
    onClick: onClick,
};
var TableEditDeleteMenuItem = {
    key: 'menuNameTableDelete',
    unlocalizedText: 'Delete',
    subItems: {
        menuNameTableDeleteColumn: 'Delete column',
        menuNameTableDeleteRow: 'Delete row',
        menuNameTableDeleteTable: 'Delete table',
    },
    onClick: onClick,
};
var TableEditMergeMenuItem = {
    key: 'menuNameTableMerge',
    unlocalizedText: 'Merge',
    subItems: {
        menuNameTableMergeAbove: 'Merge above',
        menuNameTableMergeBelow: 'Merge below',
        menuNameTableMergeLeft: 'Merge left',
        menuNameTableMergeRight: 'Merge right',
        '-': '-',
        menuNameTableMergeCells: 'Merge selected cells',
    },
    onClick: onClick,
};
var TableEditSplitMenuItem = {
    key: 'menuNameTableSplit',
    unlocalizedText: 'Split',
    subItems: {
        menuNameTableSplitHorizontally: 'Split horizontally',
        menuNameTableSplitVertically: 'Split vertically',
    },
    onClick: onClick,
};
var TableEditAlignMenuItem = {
    key: 'menuNameTableAlign',
    unlocalizedText: 'Align cell',
    subItems: {
        menuNameTableAlignLeft: 'Align left',
        menuNameTableAlignCenter: 'Align center',
        menuNameTableAlignRight: 'Align right',
        '-': '-',
        menuNameTableAlignTop: 'Align top',
        menuNameTableAlignMiddle: 'Align middle',
        menuNameTableAlignBottom: 'Align bottom',
    },
    onClick: onClick,
};
var TableEditAlignTableMenuItem = {
    key: 'menuNameTableAlignTable',
    unlocalizedText: 'Align table',
    subItems: {
        menuNameTableAlignTableLeft: 'Align left',
        menuNameTableAlignTableCenter: 'Align center',
        menuNameTableAlignTableRight: 'Align right',
    },
    onClick: onClick,
};
var TableEditCellShadeMenuItem = {
    key: 'menuNameTableCellShade',
    unlocalizedText: 'Shading',
    subItems: BackgroundColorDropDownItems,
    onClick: function (key, editor) {
        setTableCellShade(editor, ColorValues[key].lightModeColor);
    },
    itemRender: function (item, click) { return renderColorPicker(item, ColorValues, click); },
    itemClassName: getColorPickerItemClassName(),
    commandBarSubMenuProperties: {
        className: getColorPickerContainerClassName(),
    },
};
function getEditingTable(editor, node) {
    var domHelper = editor.getDOMHelper();
    var td = domHelper.findClosestElementAncestor(node, 'TD,TH');
    var table = td && domHelper.findClosestElementAncestor(td, 'table');
    return (table === null || table === void 0 ? void 0 : table.isContentEditable) ? { table: table, td: td } : null;
}
/**
 * Create a new instance of ContextMenuProvider to support table editing functionalities in context menu
 * @returns A new ContextMenuProvider
 */
export function createTableEditMenuProvider(strings) {
    return createContextMenuProvider('tableEdit', [
        TableEditInsertMenuItem,
        TableEditDeleteMenuItem,
        TableEditMergeMenuItem,
        TableEditSplitMenuItem,
        TableEditAlignMenuItem,
        TableEditAlignTableMenuItem,
        TableEditCellShadeMenuItem,
    ], strings, function (editor, node) { return !!getEditingTable(editor, node); });
}
//# sourceMappingURL=createTableEditMenuProvider.js.map