import * as React from 'react';
import { getLocalizedString } from '../../common/index';
import { mergeStyleSets } from '@fluentui/react/lib/Styling';
import { TextField } from '@fluentui/react/lib/TextField';
var classNames = mergeStyleSets({
    inputBox: {
        width: '100%',
        minWidth: '250px',
        height: '32px',
        margin: '5px 0 16px',
        borderRadius: '2px',
    },
});
/**
 * @internal
 */
export function InputDialogItem(props) {
    var itemName = props.itemName, strings = props.strings, items = props.items, currentValues = props.currentValues, onChanged = props.onChanged, onEnterKey = props.onEnterKey, rows = props.rows;
    var _a = items[itemName], labelKey = _a.labelKey, unlocalizedLabel = _a.unlocalizedLabel, autoFocus = _a.autoFocus;
    var value = currentValues[itemName];
    var onValueChange = React.useCallback(function (_, newValue) {
        onChanged(itemName, newValue);
    }, [itemName, onChanged]);
    var onKeyPress = React.useCallback(function (e) {
        if (e.key == 'Enter') {
            onEnterKey();
        }
    }, [onEnterKey]);
    return (React.createElement("div", null,
        labelKey ? React.createElement("div", null, getLocalizedString(strings, labelKey, unlocalizedLabel)) : null,
        React.createElement("div", null,
            React.createElement(TextField, { role: "textbox", type: "text", className: classNames.inputBox, value: value, onChange: onValueChange, onKeyPress: onKeyPress, autoFocus: autoFocus, rows: rows, multiline: !!rows }))));
}
//# sourceMappingURL=InputDialogItem.js.map