import * as React from 'react';
import { InputDialog } from '../component/InputDialog';
import { renderReactComponent } from '../../common/utils/renderReactComponent';
/**
 * Show a dialog with input items
 * @param uiUtilities UI utilities to help render the dialog
 * @param dialogTitleKey Localized string key for title of this dialog
 * @param unlocalizedTitle Unlocalized title string of this dialog. It will be used if a valid localized string is not found using dialogTitleKey
 * @param items Input items in this dialog
 * @param strings Localized strings
 * @param onChange An optional callback that will be invoked when input item value is changed
 */
export function showInputDialog(uiUtilities, dialogTitleKey, unlocalizedTitle, items, strings, onChange, rows) {
    return new Promise(function (resolve) {
        var disposer = null;
        var onOk = function (result) {
            disposer === null || disposer === void 0 ? void 0 : disposer();
            resolve(result);
        };
        var onCancel = function () {
            disposer === null || disposer === void 0 ? void 0 : disposer();
            resolve(null);
        };
        var component = (React.createElement(InputDialog, { dialogTitleKey: dialogTitleKey, unlocalizedTitle: unlocalizedTitle, items: items, strings: strings, onOk: onOk, onCancel: onCancel, onChange: onChange, rows: rows }));
        disposer = renderReactComponent(uiUtilities, component);
    });
}
//# sourceMappingURL=showInputDialog.js.map