"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getColorPickerDropDown = exports.renderColorPicker = void 0;
var React = require("react");
var backgroundColors_1 = require("../utils/backgroundColors");
var Styling_1 = require("@fluentui/react/lib/Styling");
var textColors_1 = require("../utils/textColors");
var getClassNamesForColorPicker_1 = require("../utils/getClassNamesForColorPicker");
var classNames = (0, Styling_1.mergeStyleSets)({
    colorSquare: {
        width: '20px',
        height: '20px',
        margin: '4px',
        borderStyle: 'solid',
        borderWidth: '2px',
        '&:hover': {
            borderColor: 'red',
        },
    },
    colorSquareBorder: {
        borderColor: 'transparent',
    },
    colorSquareBorderWhite: {
        borderColor: '#bebebe',
    },
});
/**
 * @internal
 * Render a color picker
 * @param item Color items
 * @param colorDef Definition of colors
 * @param onClick On click event handler
 */
function renderColorPicker(item, colorDef, onClick) {
    var key = item.key;
    var buttonColor = colorDef[key].lightModeColor;
    return (React.createElement("button", { onClick: function (e) { return onClick(e, item); }, title: item.text },
        React.createElement("div", { className: classNames.colorSquare +
                ' ' +
                (key == 'textColorWhite' || key == 'backgroundColorWhite'
                    ? classNames.colorSquareBorderWhite
                    : classNames.colorSquareBorder), style: {
                backgroundColor: buttonColor,
            } })));
}
exports.renderColorPicker = renderColorPicker;
/**
 * Get a drop down data object of color picker used by drop down button
 * @param colorSet The set of color, text or background
 * @returns The color picker drop down for ribbon button
 */
function getColorPickerDropDown(colorSet) {
    return {
        items: colorSet == 'background' ? backgroundColors_1.BackgroundColorDropDownItems : textColors_1.TextColorDropDownItems,
        itemClassName: (0, getClassNamesForColorPicker_1.getColorPickerItemClassName)(),
        allowLivePreview: true,
        itemRender: colorSet == 'background'
            ? function (item, onClick) { return renderColorPicker(item, backgroundColors_1.BackgroundColors, onClick); }
            : function (item, onClick) { return renderColorPicker(item, textColors_1.TextColors, onClick); },
        commandBarSubMenuProperties: {
            className: (0, getClassNamesForColorPicker_1.getColorPickerContainerClassName)(),
        },
    };
}
exports.getColorPickerDropDown = getColorPickerDropDown;
//# sourceMappingURL=renderColorPicker.js.map