"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.showInputDialog = void 0;
var React = require("react");
var InputDialog_1 = require("../component/InputDialog");
var renderReactComponent_1 = require("../../common/utils/renderReactComponent");
/**
 * Show a dialog with input items
 * @param uiUtilities UI utilities to help render the dialog
 * @param dialogTitleKey Localized string key for title of this dialog
 * @param unlocalizedTitle Unlocalized title string of this dialog. It will be used if a valid localized string is not found using dialogTitleKey
 * @param items Input items in this dialog
 * @param strings Localized strings
 * @param onChange An optional callback that will be invoked when input item value is changed
 */
function showInputDialog(uiUtilities, dialogTitleKey, unlocalizedTitle, items, strings, onChange, rows) {
    return new Promise(function (resolve) {
        var disposer = null;
        var onOk = function (result) {
            disposer === null || disposer === void 0 ? void 0 : disposer();
            resolve(result);
        };
        var onCancel = function () {
            disposer === null || disposer === void 0 ? void 0 : disposer();
            resolve(null);
        };
        var component = (React.createElement(InputDialog_1.InputDialog, { dialogTitleKey: dialogTitleKey, unlocalizedTitle: unlocalizedTitle, items: items, strings: strings, onOk: onOk, onCancel: onCancel, onChange: onChange, rows: rows }));
        disposer = (0, renderReactComponent_1.renderReactComponent)(uiUtilities, component);
    });
}
exports.showInputDialog = showInputDialog;
//# sourceMappingURL=showInputDialog.js.map