"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Rooster = void 0;
var tslib_1 = require("tslib");
var React = require("react");
var index_1 = require("../../common/index");
var Utilities_1 = require("@fluentui/react/lib/Utilities");
var roosterjs_content_model_core_1 = require("roosterjs-content-model-core");
var Theme_1 = require("@fluentui/react/lib/Theme");
/**
 * Main component of react wrapper for roosterjs
 * @param props Properties of this component
 * @returns The react component
 */
function Rooster(props) {
    var editorDiv = React.useRef(null);
    var editor = React.useRef(null);
    var theme = (0, Theme_1.useTheme)();
    var focusOnInit = props.focusOnInit, editorCreator = props.editorCreator, inDarkMode = props.inDarkMode, plugins = props.plugins;
    React.useEffect(function () {
        if (plugins && editorDiv.current) {
            var uiUtilities_1 = (0, index_1.createUIUtilities)(editorDiv.current, theme);
            plugins.forEach(function (plugin) {
                if (isReactEditorPlugin(plugin)) {
                    plugin.setUIUtilities(uiUtilities_1);
                }
            });
        }
    }, [theme, editorCreator]);
    React.useEffect(function () {
        var _a;
        if (editorDiv.current) {
            editor.current = (editorCreator || defaultEditorCreator)(editorDiv.current, props);
        }
        if (focusOnInit) {
            (_a = editor.current) === null || _a === void 0 ? void 0 : _a.focus();
        }
        return function () {
            if (editor.current) {
                editor.current.dispose();
                editor.current = null;
            }
        };
    }, [editorCreator]);
    React.useEffect(function () {
        var _a;
        (_a = editor.current) === null || _a === void 0 ? void 0 : _a.setDarkModeState(!!inDarkMode);
    }, [inDarkMode]);
    var divProps = (0, Utilities_1.getNativeProps)(props, Utilities_1.divProperties);
    return (React.createElement("div", (0, tslib_1.__assign)({ ref: editorDiv, tabIndex: 0, role: "textbox", "aria-multiline": "true" }, (divProps || {}))));
}
exports.Rooster = Rooster;
function defaultEditorCreator(div, options) {
    return new roosterjs_content_model_core_1.Editor(div, options);
}
function isReactEditorPlugin(plugin) {
    var _a;
    return !!((_a = plugin) === null || _a === void 0 ? void 0 : _a.setUIUtilities);
}
//# sourceMappingURL=Rooster.js.map